@@ -1,4 +1,5 @@
 from collections import defaultdict
+from typing import Callable
 from urllib.parse import quote, unquote
 
 from switcore.type import AsyncDrawerHandler
@@ -18,7 +19,7 @@ class PathResolver:
         for path in paths:
             self._add_path(path)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.combined_path
 
     @property
@@ -64,7 +65,7 @@ class PathResolver:
 
         return PathResolver(arr[0], paths)  # type: ignore
 
-    def _add_path(self, path: int | str):
+    def _add_path(self, path: int | str) -> None:
         assert isinstance(path, int) or isinstance(path, str), "only int or str is allowed"
 
         self._escaped_paths.append(escape(str(path)))
@@ -76,8 +77,9 @@ class ActivityRouter:
         self.handlers: dict[str, AsyncDrawerHandler] = dict()
         self.view_actions: dict[str, set[str]] = defaultdict(set)
 
-    def register(self, action_id: str, view_ids: list[str] | None = None):
-        def decorator(func):
+    def register(self, action_id: str, view_ids: list[str] | None = None) \
+            -> Callable[[AsyncDrawerHandler], AsyncDrawerHandler]:
+        def decorator(func: AsyncDrawerHandler) -> AsyncDrawerHandler:
             escaped_action_id = escape(action_id)
             self.handlers[escaped_action_id] = func
 
