@@ -5,6 +5,9 @@ from starlette.requests import Request
 from switcore.action.schemas import SwitRequest
 from switcore.auth.exception import VerificationFailedException
 from switcore.auth.signature_verification import SignatureVerifier
+from switcore.logger import get_logger
+
+logger = get_logger()
 
 
 async def get_swit_request(
@@ -25,4 +28,5 @@ async def get_swit_request(
         raise VerificationFailedException("Verification failed check your signing key")
 
     data: dict = await request.json()
+    logger.info(data)
     return SwitRequest(**data)
