@@ -6,7 +6,7 @@ from switcore.async_httpclient import CustomAsyncHTTPClient
 @sort_by_name
 async def get_all_workspaces_recursive(
         http_client: CustomAsyncHTTPClient,
-        offset: str | None = None  # type: ignore
+        offset: str | None = None
 ) -> list[Workspace]:
     params: dict = {
         "limit": 50,
@@ -21,13 +21,13 @@ async def get_all_workspaces_recursive(
     data = data.get('data', {})
 
     workspaces_data: list[dict] = data.get('workspaces', [])
-    offset: str | None = data.get('offset', None)
+    new_offset: str | None = data.get('offset', None)
 
     if len(workspaces_data) == 0:
         return []
 
     workspaces = [Workspace(**workspace) for workspace in workspaces_data]
-    next_workspaces = await get_all_workspaces_recursive(http_client, offset)
+    next_workspaces = await get_all_workspaces_recursive(http_client, new_offset)
     return workspaces + next_workspaces
 
 
