@@ -21,13 +21,13 @@ def get_sync_all_workspaces_recursive(
     data = data.get('data', {})
 
     workspaces_data: list[dict] = data.get('workspaces', [])
-    offset: str | None = data.get('offset', None)
+    new_offset: str | None = data.get('offset', None)
 
     if len(workspaces_data) == 0:
         return []
 
     workspaces = [Workspace(**workspace) for workspace in workspaces_data]
-    next_workspaces = get_sync_all_workspaces_recursive(http_client, offset)
+    next_workspaces = get_sync_all_workspaces_recursive(http_client, new_offset)
     return workspaces + next_workspaces
 
 
