@@ -8,8 +8,8 @@ def get_oauth() -> OAuth2:
     swit_client_id: str | None = os.getenv('SWIT_CLIENT_ID', None)
     swit_client_secret: str | None = os.getenv('SWIT_CLIENT_SECRET', None)
     base_url: str | None = os.getenv('BASE_URL', None)
-    bot_redirect_url: str | None = os.getenv('BOT_REDIRECT_URL', "/auth/callback/bot")
-    user_redirect_url: str | None = os.getenv('USER_REDIRECT_URL', "/auth/callback/user")
+    bot_redirect_url: str = os.getenv('BOT_REDIRECT_URL', "/auth/callback/bot")
+    user_redirect_url: str = os.getenv('USER_REDIRECT_URL', "/auth/callback/user")
 
     assert swit_client_id is not None, "SWIT_CLIENT_ID is not set check .env file"
     assert swit_client_secret is not None, "SWIT_CLIENT_SECRET is not set check .env file"
