@@ -97,12 +97,12 @@ class OAuth2(BaseModel):
                 headers=self.request_headers,
             )
 
-            data: dict[str, Any] = response.json()
+            result: dict[str, Any] = response.json()
 
             if response.status_code >= 400:
-                raise ValueError(data)
+                raise ValueError(result)
 
-            return SwitToken(**data)
+            return SwitToken(**result)
 
     async def refresh_token(self, refresh_token: str) -> SwitToken:
         async with httpx.AsyncClient() as client:
