@@ -16,9 +16,9 @@ class AppRepository(RepositoryBase):
             refresh_token: str,
             iss: str,
             apps_id: str,
-            cmp_id: str | None
+            cmp_id: str
     ) -> App:
-        token = App(  # type: ignore
+        token = App(
             access_token=access_token,
             refresh_token=refresh_token,
             iss=iss,
