@@ -1,4 +1,4 @@
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict
 
 
 class SwitToken(BaseModel):
@@ -14,7 +14,7 @@ class Payload(BaseModel):
     exp: int
     iss: str
     sub: str
-    cmp_id: str | None
+    cmp_id: str | None = None
     apps_id: str
     app_user_id: str
     issue_type: int
@@ -25,5 +25,4 @@ class UserSchema(BaseModel):
     access_token: str
     refresh_token: str
 
-    class Config:
-        orm_mode = True
+    model_config = ConfigDict(from_attributes=True)
