@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Literal
 
 from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.Icon import Icon
@@ -7,7 +7,7 @@ from switcore.ui.element_components import StaticAction
 
 class Button(SwitBaseModel):
     id: Optional[str] = None
-    type: str = "button"
+    type: Literal['button'] = 'button'
     label: str | None = None
     style: str | None = None
     disabled: bool | None = None
