@@ -1,3 +1,4 @@
+from typing import Literal
 from enum import Enum
 
 from switcore.pydantic_base_model import SwitBaseModel
@@ -41,7 +42,7 @@ class VerticalAlignmentTypes(str, Enum):
 
 
 class CollectionEntry(SwitBaseModel):
-    type: str = "collection_entry"
+    type: Literal['collection_entry'] = 'collection_entry'
     start_section: Image | None = None
     text_sections: list[TextSection]
     vertical_alignment: VerticalAlignmentTypes = VerticalAlignmentTypes.top
