@@ -1,3 +1,7 @@
+from typing import Literal
+
+from pydantic import Field
+
 from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.button import Button
 from switcore.ui.datepicker import DatePicker
@@ -5,8 +9,6 @@ from switcore.ui.select import Select
 
 
 class Container(SwitBaseModel):
-    type: str = "container"
-    elements: list[Select | Button | DatePicker]
+    type: Literal['container'] = 'container'
+    elements: list[Select | Button | DatePicker] = Field(discriminator='resource_type')
 
-    class Config:
-        smart_union = True
