@@ -1,8 +1,10 @@
+from typing import Literal
+
 from switcore.pydantic_base_model import SwitBaseModel
 
 
 class DatePicker(SwitBaseModel):
-    type: str = "datepicker"
+    type: Literal['datepicker'] = 'datepicker'
     action_id: str
     placeholder: str | None = None
     trigger_on_input: bool = False
