@@ -1,5 +1,7 @@
+from typing import Literal
+
 from switcore.pydantic_base_model import SwitBaseModel
 
 
 class Divider(SwitBaseModel):
-    type: str = "divider"
+    type: Literal['divider'] = 'divider'
\ No newline at end of file
