@@ -1,6 +1,7 @@
 from enum import Enum
+from typing import Any
 
-from pydantic import root_validator
+from pydantic import model_validator
 
 from switcore.pydantic_base_model import SwitBaseModel
 
@@ -23,8 +24,9 @@ class TagStyle(SwitBaseModel):
     class Config:
         use_enum_values = True
 
-    @root_validator
-    def check_color_and_shape(cls, values):
+    @model_validator(mode='before')
+    @classmethod
+    def check_color_and_shape(cls, values: dict[str, Any]) -> dict[str, Any]:
         color: TagColorTypes | None = values.get('color')
         shape: TagShapeTypes | None = values.get('shape')
         if color is None and shape is None:
