@@ -1,4 +1,5 @@
 from enum import Enum
+from typing import Literal
 
 from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.element_components import StaticAction
@@ -43,9 +44,9 @@ def get_file_type(file_extension: str) -> FileTypes:
 
 
 class File(SwitBaseModel):
-    type: str = "file"
+    type: Literal['file'] = 'file'
     file_type: FileTypes
     file_size: int
     file_name: str
-    action_id: str | None
-    static_action: StaticAction | None
+    action_id: str | None = None
+    static_action: StaticAction | None = None
