@@ -1,3 +1,5 @@
+from typing import Literal
+
 from pydantic import Field
 
 from switcore.pydantic_base_model import SwitBaseModel
@@ -5,6 +7,6 @@ from switcore.ui.interactive_image import InteractiveImage
 
 
 class ImageGrid(SwitBaseModel):
-    type: str = "image_grid"
+    type: Literal['image_grid'] = 'image_grid'
     images: list[InteractiveImage]
     column_count: int = Field(..., ge=2, le=3)
