@@ -1,4 +1,5 @@
 from enum import Enum
+from typing import Literal
 
 from switcore.pydantic_base_model import SwitBaseModel
 
@@ -9,9 +10,9 @@ class InputVariant(str, Enum):
 
 
 class Input(SwitBaseModel):
-    type: str = 'text_input'
+    type: Literal['text_input'] = 'text_input'
     action_id: str
-    placeholder: str | None
+    placeholder: str | None = None
     trigger_on_input: bool = False
-    value: str | None
+    value: str | None = None
     variant: InputVariant = InputVariant.text
