@@ -1,8 +1,10 @@
+from typing import Literal
+
 from switcore.pydantic_base_model import SwitBaseModel
 
 
 class SearchInput(SwitBaseModel):
-    type: str = 'search_input'
+    type: Literal['search_input'] = 'search_input'
     action_id: str
     placeholder: str | None
     value: str | None
