@@ -1,3 +1,5 @@
+from typing import Literal
+
 from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.Icon import Icon
 from switcore.ui.button import Button
@@ -8,8 +10,8 @@ class IntegratedService(SwitBaseModel):
 
 
 class SignInPage(SwitBaseModel):
+    type: Literal['sign_in_page'] = 'sign_in_page'
     id: str | None = None
-    type: str = "sign_in_page"
     integrated_service: IntegratedService
     title: str
     description: str
