@@ -1,3 +1,5 @@
+from typing import Literal
+
 from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.select_item import SelectItem
 
@@ -6,6 +8,6 @@ class Tabs(SwitBaseModel):
     """
         An element representing an array of tabs.
     """
-    type: str = "tabs"
+    type: Literal['tabs'] = 'tabs'
     tabs: list[SelectItem]
     value: str
