@@ -1,6 +1,7 @@
 from enum import Enum
+from typing import Literal
 
-from pydantic import validator
+from pydantic import model_validator
 
 from switcore.pydantic_base_model import SwitBaseModel
 
@@ -17,20 +18,21 @@ class TextParagraphSizeTypes(str, Enum):
 
 
 class TextParagraphStyle(SwitBaseModel):
+    # TODO : TextParagraphStyle 스펙 확인 필요
     bold: bool = False
     color: TextParagraphColorTypes = TextParagraphColorTypes.gray900
     size: TextParagraphSizeTypes = TextParagraphSizeTypes.medium
     max_lines: int = 0
 
-    @validator('max_lines', pre=True, always=True)
-    def check_max_lines(cls, v):
-        if v < 0 or v > 2:
+    @model_validator(mode='after')
+    def check_max_lines(self):
+        if self.max_lines < 0 or self.max_lines > 2:
             raise ValueError('max_lines must be between 0 and 2 inclusive.')
-        return v
+        return self
 
 
 class TextParagraph(SwitBaseModel):
-    type: str = "text"
+    type: Literal['text'] = 'text'
     markdown: bool = False
     content: str
     style: TextParagraphStyle | None = None
