@@ -1,4 +1,5 @@
 from enum import Enum
+from typing import Literal
 
 from switcore.pydantic_base_model import SwitBaseModel
 
@@ -10,9 +11,9 @@ class TextareaSizeTypes(str, Enum):
 
 
 class Textarea(SwitBaseModel):
-    type: str = "textarea"
+    type: Literal['textarea'] = 'textarea'
     action_id: str
-    placeholder: str | None
-    value: str | None
+    placeholder: str | None = None
+    value: str | None = None
     height: TextareaSizeTypes = TextareaSizeTypes.small
     disabled: bool = False
